Documentation — mpathic 0.0.1 documentation

# Documentation

- mpa.SimulateLibrary
  - Class Details
- mpa.SimulateSort
  - Overview
  - Usage
  - Example Input and Output
  - Class Details
- mpa.ProfileFreq
  - Class Details
- mpa.ProfileMutrate
  - Class Details
- mpa.ProfileInfo
  - Class Details
- mpa.LearnModel
  - Overview
  - Example Input and Output
  - Class Details
- mpa.EvaluateModel
  - Overview
  - Usage
  - Example Input and Output
  - Class Details
- mpa.ScanModel
  - Class Details

## mpa.demo()

`mpathic.` `demo`(example='simulation')

  Runs a demonstration of mpathic.

  Parameters: | example: (str) A string specifying which demo to run. Must be ‘simulation’, ‘profile’, or ‘modeling’.
  Returns: | None.